Changelog
=========

`1.0.0`_ (2015-Nov-02)
----------------------
- Add :func:`coercion.stringify`
- Add :func:`coercion.normalize_collection`

.. _Next Release: https://github.com/dave-shawley/coercion/compare/1.0.0...master
.. _1.0.0: https://github.com/dave-shawley/coercion/compare/0.0.0...1.0.0
